@@ -16,6 +16,19 @@ class MailCreatedMessage extends AbstractMessage
     public function __construct()
     {
         parent::__construct();
+        $this->data = [
+            'mail' => null,
+            'project' => null,
+            'sender' => null,
+            'date' => null,
+            'recipients' => null,
+            'subject' => null,
+            'message' => null,
+            'attachments' => null,
+            'raw' => null,
+            'html' => null,
+            'metadata' => null
+        ];
         $this->type = MessageType::MAIL_CREATED;
     }
 
@@ -67,14 +80,14 @@ class MailCreatedMessage extends AbstractMessage
         return $this;
     }
 
-    public function getRecipient(): ?string
+    public function getRecipients(): array
     {
-        return $this->data['recipient'];
+        return $this->data['recipients'];
     }
 
-    public function setRecipient(?string $recipient): self
+    public function setRecipients(array $recipients): self
     {
-        $this->data['recipient'] = $recipient;
+        $this->data['recipients'] = $recipients;
 
         return $this;
     }
@@ -138,4 +151,37 @@ class MailCreatedMessage extends AbstractMessage
 
         return $this;
     }
+
+    public function getMetadata(): ?array
+    {
+        return $this->data['metadata'];
+    }
+
+    public function setMetadata(?array $metadata): self
+    {
+        $this->data['metadata'] = $metadata;
+
+        return $this;
+    }
+
+    public function addMetadata(array $metadata): self
+    {
+        if (false === in_array($metadata, $this->data['metadata'])) {
+            $this->data['metadata'][] = $metadata;
+        }
+
+        return $this;
+    }
+
+    public function removeMetadata(array $metadata): self
+    {
+        if (true === in_array($metadata, $this->data['metadata'])) {
+            $this->data['metadata'] = array_filter($this->data['metadata'], function ($element) use ($metadata) {
+                return $element !== $metadata;
+            });
+        }
+
+        return $this;
+    }
+
 }
